API
===

.. currentmodule:: gcsfs.core

.. autosummary::
   GCSFileSystem
   GCSFileSystem.cat
   GCSFileSystem.du
   GCSFileSystem.exists
   GCSFileSystem.get
   GCSFileSystem.glob
   GCSFileSystem.info
   GCSFileSystem.ls
   GCSFileSystem.mkdir
   GCSFileSystem.mv
   GCSFileSystem.open
   GCSFileSystem.put
   GCSFileSystem.read_block
   GCSFileSystem.rm
   GCSFileSystem.tail
   GCSFileSystem.touch
   GCSFileSystem.get_mapper

.. autosummary::
   GCSFile
   GCSFile.close
   GCSFile.flush
   GCSFile.info
   GCSFile.read
   GCSFile.seek
   GCSFile.tell
   GCSFile.write

.. currentmodule:: gcsfs.mapping

.. currentmodule:: gcsfs.core

.. autoclass:: GCSFileSystem
   :members:

.. autoclass:: GCSFile
   :members:

.. currentmodule:: gcsfs.mapping
